(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[777],{836:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/layout",function(){return t(2997)}])},4918:function(e,n,t){"use strict";t.r(n),t.d(n,{default:function(){return a}});var r=t(5893),i=t(1683),s=t(2712),u=t(4761),c=t(9332),l=t(927);function a(e){let{children:n}=e,t=(0,s.S)();return t.compat=!0,(0,c.useServerInsertedHTML)(()=>(0,r.jsx)("style",{"data-emotion":"".concat(t.key," ").concat(Object.keys(t.inserted).join(" ")),dangerouslySetInnerHTML:{__html:Object.values(t.inserted).join(" ")}})),(0,r.jsx)(i.C,{value:t,children:(0,r.jsx)(u.Me,{theme:l.r,withGlobalStyles:!0,withNormalizeCSS:!0,children:n})})}},2997:function(e,n,t){"use strict";t.r(n),t.d(n,{default:function(){return l}});var r=t(5893),i=t(8664),s=t(1806),u=t(208),c=t(4918);function l(e){let{children:n}=e;return(0,r.jsxs)("html",{children:[(0,r.jsx)("head",{}),(0,r.jsx)("body",{children:(0,r.jsx)(c.default,{children:(0,r.jsx)(u.Z,{children:(0,r.jsx)("div",{"data-theme":"greenheart",children:(0,r.jsx)(i.V,{navbar:(0,r.jsx)(s.X,{}),children:n})})})})})]})}}},function(e){e.O(0,[774,888,179],function(){return e(e.s=836)}),_N_E=e.O()}]);