{% load static %}
<!DOCTYPE html>
<html>
 <head>
  <meta charset="utf-8"/>
  <meta content="minimum-scale=1, initial-scale=1, width=device-width" name="viewport"/>
  <link href="ui_kit/components/components.css" type="text/css"/>
  <title>
   Logs
  </title>
  <meta content="4" name="next-head-count"/>
  <link as="font" crossorigin="anonymous" href='{% static "/studio/_next/static/media/3478b6abef19b3b3.p.woff2" %}' rel="preload" type="font/woff2"/>
  <link as="style" href='{% static "/studio/_next/static/css/cc49d8d41e055bcd.css" %}' rel="preload"/>
  <link data-n-p="" href='{% static "/studio/_next/static/css/cc49d8d41e055bcd.css" %}' rel="stylesheet"/>
  <noscript data-n-css="">
  </noscript>
  <script defer="" nomodule="" src='{% static "/studio/_next/static/chunks/polyfills-c67a75d1b6f99dc8.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/webpack-620c68345e03c539.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/framework-3b5a00d5d7e8d93b.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/main-1844b67c68085ff6.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/pages/_app-3023bf5945430c06.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/289-4a13cf748d6cfb17.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/358-5eea73ebeed3f5bf.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/30-825cca92eb40c60a.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/pages/logs-a311b718d668cc55.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/iiD7YBuGak2wjNaXaNppg/_buildManifest.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/iiD7YBuGak2wjNaXaNppg/_ssgManifest.js" %}'>
  </script>
  <style data-emotion="mantine-global zl4edr">
   html{font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%;-ms-text-size-adjust:100%;text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section,figcaption,figure,main{display:block;}h1{font-size:2em;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background:transparent;text-decoration-skip:objects;}a:active,a:hover{outline-width:0;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;}b,strong{font-weight:bolder;}code,kbp,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sup{top:-0.5em;}sub{bottom:-0.25em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;vertical-align:middle;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,[type=reset],[type=submit]{-webkit-appearance:button;}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=checkbox],[type=radio]{box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto;}[type=search]{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}[type=search]::-webkit-search-cancel-button,[type=search]::-webkit-search-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;-moz-appearance:button;-ms-appearance:button;appearance:button;font:inherit;}details,menu{display:block;}summary{display:-webkit-box;display:-webkit-list-item;display:-ms-list-itembox;display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}
  </style>
  <style data-emotion="mantine-global 1j3c5om">
   *,*::before,*::after{box-sizing:border-box;}html{-webkit-print-color-scheme:light;color-scheme:light;}body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;background-color:#fff;color:#000;line-height:1.55;font-size:16px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;}
  </style>
  <style data-emotion="mantine-global wo6pb2">
  </style>
  <style data-emotion="mantine-global 563mdc">
   :root{--mantine-navbar-width:80px;}
  </style>
  <style data-emotion="mantine ibbm6b 13jfpqk osix87 hhjyz1 8od8ev p7xtuc 1h8zs6q hv1yhu 1l34ikq khtkeg 11q5icf zf12j9 3xbgk5 qo1k2 1lis5e 1m3pqry 12sbrde 874jzt ila8jt sbeq40 y1lrl8 5w6rop 14jt8i5 5f6x53 bl0c8b 1pws4j5 152iqvs n93y9k 1elrvk9 1jcn111 145a07o">
   .mantine-ibbm6b{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;box-sizing:border-box;}.mantine-13jfpqk{-webkit-flex:1;-ms-flex:1;flex:1;width:100vw;box-sizing:border-box;min-height:100vh;padding-top:calc(var(--mantine-header-height, 0px) + 16px);padding-bottom:calc(var(--mantine-footer-height, 0px) + 16px);padding-left:calc(var(--mantine-navbar-width, 0px) + 16px);padding-right:calc(var(--mantine-aside-width, 0px) + 16px);}@media (max-width: -1px){.mantine-13jfpqk{padding-right:16px;}}.mantine-osix87{box-sizing:border-box;}.mantine-hhjyz1{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;top:var(--mantine-header-height);left:0;bottom:0;z-index:100;height:100vh;width:80px;position:fixed;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;background-color:#fff;border-right:1px solid #e9ecef;padding:16px;}@media (max-width: 991px){.mantine-hhjyz1[data-hidden]{display:none;}}.mantine-8od8ev{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;}.mantine-p7xtuc{margin-top:50px;-webkit-flex:1;-ms-flex:1;flex:1;box-sizing:border-box;}.mantine-1h8zs6q{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;gap:0;}.mantine-hv1yhu{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;width:50px;height:50px;border-radius:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;color:#495057;}.mantine-hv1yhu:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-hv1yhu:focus:not(:focus-visible){outline:none;}.mantine-hv1yhu:hover{background-color:#f8f9fa;}.mantine-1l34ikq{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;width:50px;height:50px;border-radius:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;color:#495057;}.mantine-1l34ikq:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1l34ikq:focus:not(:focus-visible){outline:none;}.mantine-1l34ikq:hover{background-color:#f8f9fa;}.mantine-1l34ikq,.mantine-1l34ikq:hover{background-color:rgba(255, 244, 230, 1);color:#fd7e14;}.mantine-khtkeg{-webkit-flex:0;-ms-flex:0;flex:0;box-sizing:border-box;}.mantine-11q5icf{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;}.mantine-zf12j9{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;color:inherit;font-size:inherit;line-height:1.55;-webkit-text-decoration:none;text-decoration:none;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;font-weight:700;font-size:22px;line-height:1.4;margin:0;margin-bottom:24px;}.mantine-zf12j9:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-zf12j9:focus:not(:focus-visible){outline:none;}.mantine-3xbgk5{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;height:100%;overflow:visible;}.mantine-qo1k2{white-space:nowrap;height:100%;overflow:hidden;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;}.mantine-1lis5e{border:0;border-top-width:1px;border-top-color:#ced4da;border-top-style:solid;margin:0;}.mantine-1m3pqry{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;line-height:1.55;}.mantine-12sbrde{position:relative;}.mantine-874jzt{outline:0;-webkit-tap-highlight-color:transparent;display:block;-webkit-text-decoration:none;text-decoration:none;color:#000;background-color:#fff;box-sizing:border-box;border-radius:8px;box-shadow:0 1px 3px rgba(0, 0, 0, 0.05),rgba(0, 0, 0, 0.05) 0px 20px 25px -5px,rgba(0, 0, 0, 0.04) 0px 10px 10px -5px;border:1px solid #dee2e6;position:relative;overflow:hidden;background-color:#fff;margin:0 auto;padding:30px;width:90%;height:90%;}.mantine-ila8jt{outline:0;-webkit-tap-highlight-color:transparent;display:block;-webkit-text-decoration:none;text-decoration:none;color:#000;background-color:#fff;box-sizing:border-box;border-radius:4px;box-shadow:none;border:1px solid #dee2e6;position:relative;overflow:hidden;background-color:#fff;max-height:90vh;padding:16px;padding-top:0;padding-right:0;padding-left:0;}.mantine-sbeq40{padding:10px;}.mantine-y1lrl8{display:inline-block;font-size:12px;font-weight:500;color:#212529;word-break:break-word;cursor:default;-webkit-tap-highlight-color:transparent;}.mantine-5w6rop{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;height:30px;-webkit-tap-highlight-color:transparent;line-height:28px;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;resize:none;box-sizing:border-box;font-size:12px;width:100%;color:#000;display:block;text-align:left;min-height:30px;padding-left:10px;padding-right:10px;border-radius:4px;border:1px solid #ced4da;background-color:#fff;-webkit-transition:border-color 100ms ease;transition:border-color 100ms ease;}.mantine-5w6rop:disabled{background-color:#f1f3f5;color:#909296;opacity:0.6;cursor:not-allowed;}.mantine-5w6rop:disabled::-webkit-input-placeholder{color:#909296;}.mantine-5w6rop:disabled::-moz-placeholder{color:#909296;}.mantine-5w6rop:disabled:-ms-input-placeholder{color:#909296;}.mantine-5w6rop:disabled::placeholder{color:#909296;}.mantine-5w6rop::-webkit-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-5w6rop::-moz-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-5w6rop:-ms-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-5w6rop::placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-5w6rop::-webkit-inner-spin-button,.mantine-5w6rop::-webkit-outer-spin-button,.mantine-5w6rop::-webkit-search-decoration,.mantine-5w6rop::-webkit-search-cancel-button,.mantine-5w6rop::-webkit-search-results-button,.mantine-5w6rop::-webkit-search-results-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}.mantine-5w6rop[type=number]{-moz-appearance:textfield;}.mantine-5w6rop:focus,.mantine-5w6rop:focus-within{outline:none;border-color:#fd7e14;}.mantine-14jt8i5{margin-top:10px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-webkit-justify-content:space-between;justify-content:space-between;}.mantine-5f6x53{box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:start;-ms-flex-pack:start;-webkit-justify-content:flex-start;justify-content:flex-start;gap:16px;}.mantine-5f6x53>*{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;}.mantine-bl0c8b{position:absolute;top:0;bottom:0;right:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;width:24px;pointer-events:none;}.mantine-1pws4j5{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;height:30px;-webkit-tap-highlight-color:transparent;line-height:28px;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;resize:none;box-sizing:border-box;font-size:12px;width:100%;color:#000;display:block;text-align:left;min-height:30px;padding-left:10px;padding-right:24px;border-radius:4px;border:1px solid #ced4da;background-color:#fff;-webkit-transition:border-color 100ms ease;transition:border-color 100ms ease;}.mantine-1pws4j5:disabled{background-color:#f1f3f5;color:#909296;opacity:0.6;cursor:not-allowed;}.mantine-1pws4j5:disabled::-webkit-input-placeholder{color:#909296;}.mantine-1pws4j5:disabled::-moz-placeholder{color:#909296;}.mantine-1pws4j5:disabled:-ms-input-placeholder{color:#909296;}.mantine-1pws4j5:disabled::placeholder{color:#909296;}.mantine-1pws4j5::-webkit-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-1pws4j5::-moz-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-1pws4j5:-ms-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-1pws4j5::placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-1pws4j5::-webkit-inner-spin-button,.mantine-1pws4j5::-webkit-outer-spin-button,.mantine-1pws4j5::-webkit-search-decoration,.mantine-1pws4j5::-webkit-search-cancel-button,.mantine-1pws4j5::-webkit-search-results-button,.mantine-1pws4j5::-webkit-search-results-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}.mantine-1pws4j5[type=number]{-moz-appearance:textfield;}.mantine-1pws4j5:focus,.mantine-1pws4j5:focus-within{outline:none;border-color:#fd7e14;}.mantine-1pws4j5:not(:disabled){cursor:pointer;}.mantine-1pws4j5:not(:disabled)::selection{background-color:transparent;}.mantine-152iqvs{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;border:1px solid transparent;background-color:rgba(255, 244, 230, 1);color:#fd7e14;position:relative;height:28px;min-height:28px;width:28px;min-width:28px;border-radius:4px;padding:0;line-height:1;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;}.mantine-152iqvs:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-152iqvs:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-152iqvs:hover{background-color:rgba(255, 232, 204, 0.65);}}@media (hover: none){.mantine-152iqvs:active{background-color:rgba(255, 232, 204, 0.65);}}.mantine-152iqvs:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-152iqvs:disabled,.mantine-152iqvs[data-disabled]{color:#ced4da;cursor:not-allowed;background-color:#f1f3f5;border-color:#f1f3f5;background-image:none;pointer-events:none;}.mantine-152iqvs:disabled:active,.mantine-152iqvs[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-152iqvs[data-loading]{pointer-events:none;}.mantine-152iqvs[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}.mantine-n93y9k{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;}.mantine-n93y9k [data-button]:first-of-type{border-bottom-right-radius:0;border-top-right-radius:0;border-right-width:0.5px;}.mantine-n93y9k [data-button]:last-of-type{border-top-left-radius:0;border-bottom-left-radius:0;border-left-width:0.5px;}.mantine-n93y9k [data-button]:not(:first-of-type):not(:last-of-type){border-radius:0;border-left-width:0.5px;border-right-width:0.5px;}.mantine-n93y9k [data-button]+[data-button]{margin-left:-1px;}@media (min-resolution: 192dpi){.mantine-n93y9k [data-button]+[data-button]{margin-left:0;}}.mantine-1elrvk9{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;height:30px;padding-left:14px;padding-right:14px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;display:inline-block;width:auto;border-radius:4px;font-weight:600;position:relative;line-height:1;font-size:12px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;border:1px solid #868e96;background-color:transparent;color:#868e96;}.mantine-1elrvk9:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1elrvk9:focus:not(:focus-visible){outline:none;}.mantine-1elrvk9:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1elrvk9:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-1elrvk9:hover{background-color:rgba(248, 249, 250, 0.35);}}@media (hover: none){.mantine-1elrvk9:active{background-color:rgba(248, 249, 250, 0.35);}}.mantine-1elrvk9:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-1elrvk9:disabled,.mantine-1elrvk9[data-disabled]{border-color:transparent;background-color:#e9ecef;color:#adb5bd;cursor:not-allowed;background-image:none;pointer-events:none;}.mantine-1elrvk9:disabled:active,.mantine-1elrvk9[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-1elrvk9[data-loading]{pointer-events:none;}.mantine-1elrvk9[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}.mantine-1jcn111{outline:0;-webkit-tap-highlight-color:transparent;display:block;-webkit-text-decoration:none;text-decoration:none;color:#000;background-color:#fff;box-sizing:border-box;border-radius:4px;box-shadow:none;position:relative;overflow:hidden;background-color:#fff;background:#FAFAFA;height:500px;overflow:auto;text-rendering:optimizeLegibility;padding:16px;}.mantine-145a07o{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;width:100%;border-collapse:collapse;caption-side:top;color:#000;line-height:1.55;border:1px solid #dee2e6;word-break:break-word;font-family:monospace;}.mantine-145a07o caption{margin-top:0;margin-bottom:10px;font-size:14px;color:#868e96;}.mantine-145a07o thead tr th,.mantine-145a07o tfoot tr th{text-align:left;font-weight:bold;color:#495057;font-size:12px;padding:7px 10px;}.mantine-145a07o thead tr th{border-bottom:1px solid #dee2e6;}.mantine-145a07o tfoot tr th{border-top:1px solid #dee2e6;}.mantine-145a07o tbody tr td{padding:7px 10px;border-bottom:1px solid #dee2e6;font-size:12px;}.mantine-145a07o tbody tr:last-of-type td{border-bottom:none;}.mantine-145a07o[data-striped] tbody tr:nth-of-type(odd){background-color:#f8f9fa;}@media (hover: hover){.mantine-145a07o[data-hover] tbody tr:hover{background-color:#f1f3f5;}}@media (hover: none){.mantine-145a07o[data-hover] tbody tr:active{background-color:#f1f3f5;}}
  </style>
  <script>
   window.django = {is_authenticated: "{{ request.user.is_authenticated }}" === "True" ? true : false, user: "{{request.user}}"};
  </script>
 </head>
 <body>
  <div id="__next">
   <script src='{% static "/studio/ui_kit/components/components.esm.js" %}' type="module">
   </script>
   <script nomodule="" src='{% static "/studio/ui_kit/components/components.js" %}'>
   </script>
   <style data-emotion="css-global zl4edr">
    html{font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%;-ms-text-size-adjust:100%;text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section,figcaption,figure,main{display:block;}h1{font-size:2em;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background:transparent;text-decoration-skip:objects;}a:active,a:hover{outline-width:0;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;}b,strong{font-weight:bolder;}code,kbp,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sup{top:-0.5em;}sub{bottom:-0.25em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;vertical-align:middle;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,[type=reset],[type=submit]{-webkit-appearance:button;}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=checkbox],[type=radio]{box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto;}[type=search]{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}[type=search]::-webkit-search-cancel-button,[type=search]::-webkit-search-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;-moz-appearance:button;-ms-appearance:button;appearance:button;font:inherit;}details,menu{display:block;}summary{display:-webkit-box;display:-webkit-list-item;display:-ms-list-itembox;display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}
   </style>
   <style data-emotion="css-global 1j3c5om">
    *,*::before,*::after{box-sizing:border-box;}html{-webkit-print-color-scheme:light;color-scheme:light;}body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;background-color:#fff;color:#000;line-height:1.55;font-size:16px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;}
   </style>
   <style data-emotion="css-global wo6pb2">
   </style>
   <div data-theme="greenheart">
    <div class="mantine-AppShell-root mantine-osix87">
     <div class="mantine-ibbm6b mantine-AppShell-body">
      <nav class="mantine-Navbar-root mantine-hhjyz1">
       <div class="mantine-8od8ev">
        <img alt="Jaseci Logo" height="42" src="/static/studio/Jaseci-Submark.png" width="40"/>
       </div>
       <div class="mantine-p7xtuc">
        <div class="mantine-Stack-root mantine-1h8zs6q">
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-home-2" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="5 12 3 12 12 3 21 12 19 12">
           </polyline>
           <path d="M5 12v7a2 2 0 0 0 2 2h10a2 2 0 0 0 2 -2v-7">
           </path>
           <rect height="4" width="4" x="10" y="12">
           </rect>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-gauge" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <circle cx="12" cy="12" r="9">
           </circle>
           <circle cx="12" cy="12" r="1">
           </circle>
           <line x1="13.41" x2="16" y1="10.59" y2="8">
           </line>
           <path d="M7 12a5 5 0 0 1 5 -5">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-vector-bezier-circle" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <rect height="4" rx="1" width="4" x="3" y="10">
           </rect>
           <rect height="4" rx="1" width="4" x="17" y="10">
           </rect>
           <rect height="4" rx="1" width="4" x="10" y="3">
           </rect>
           <rect height="4" rx="1" width="4" x="10" y="17">
           </rect>
           <path d="M19 10a5 5 0 0 0 -5 -5">
           </path>
           <path d="M19 14a5 5 0 0 1 -5 5">
           </path>
           <path d="M5 14a5 5 0 0 0 5 5">
           </path>
           <path d="M5 10a5 5 0 0 1 5 -5">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-1l34ikq" type="button">
          <svg class="icon icon-tabler icon-tabler-prompt" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="5 7 10 12 5 17">
           </polyline>
           <line x1="13" x2="19" y1="17" y2="17">
           </line>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-server-bolt" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <rect height="8" rx="3" width="18" x="3" y="4">
           </rect>
           <path d="M15 20h-9a3 3 0 0 1 -3 -3v-2a3 3 0 0 1 3 -3h12">
           </path>
           <path d="M7 8v.01">
           </path>
           <path d="M7 16v.01">
           </path>
           <path d="M20 15l-2 3h3l-2 3">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-code" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="7 8 3 12 7 16">
           </polyline>
           <polyline points="17 8 21 12 17 16">
           </polyline>
           <line x1="14" x2="10" y1="4" y2="20">
           </line>
          </svg>
         </button>
        </div>
       </div>
       <div class="mantine-khtkeg">
        <div class="mantine-Stack-root mantine-1h8zs6q">
        </div>
       </div>
       <style data-emotion="css-global 563mdc">
        :root{--mantine-navbar-width:80px;}
       </style>
      </nav>
      <main class="mantine-13jfpqk mantine-AppShell-main">
       <div class="mantine-11q5icf">
        <div class="mantine-Paper-root mantine-Card-root mantine-874jzt">
         <h3 class="mantine-Text-root mantine-Title-root mantine-zf12j9">
          Logs
         </h3>
         <div class="mantine-Paper-root mantine-Card-root mantine-ila8jt">
          <div class="mantine-sbeq40">
           <div class="mantine-InputWrapper-root mantine-TextInput-root mantine-1m3pqry">
            <label class="mantine-InputWrapper-label mantine-TextInput-label mantine-y1lrl8" for="mantine-Rmlam6" id="mantine-Rmlam6-label">
             Filter
            </label>
            <div class="mantine-Input-wrapper mantine-TextInput-wrapper mantine-12sbrde">
             <input aria-invalid="false" class="mantine-Input-input mantine-TextInput-input mantine-5w6rop" id="mantine-Rmlam6" placeholder="Enter search term e.g jaseci, jaseci|objects, anything" spellcheck="false" type="text" value=""/>
            </div>
           </div>
           <div class="mantine-14jt8i5">
            <div class="mantine-Group-root mantine-5f6x53">
             <div class="mantine-InputWrapper-root mantine-Select-root mantine-1m3pqry">
              <div aria-controls="mantine-Rb6lam6" aria-expanded="false" aria-haspopup="listbox" class="" role="combobox" tabindex="-1">
               <input type="hidden" value="realTime"/>
               <div class="mantine-Input-wrapper mantine-Select-wrapper mantine-12sbrde">
                <input aria-autocomplete="list" aria-invalid="false" aria-label="Choose Time" autocomplete="off" class="mantine-Input-input mantine-Select-input mantine-1pws4j5" data-mantine-stop-propagation="false" id="mantine-Rb6lam6" placeholder="Choose Time" readonly="" type="search" value="Real-time"/>
                <div class="mantine-bl0c8b mantine-Input-rightSection mantine-Select-rightSection">
                 <svg data-chevron="true" fill="none" height="14" style="color:#868e96" viewbox="0 0 15 15" width="14" xmlns="http://www.w3.org/2000/svg">
                  <path clip-rule="evenodd" d="M4.93179 5.43179C4.75605 5.60753 4.75605 5.89245 4.93179 6.06819C5.10753 6.24392 5.39245 6.24392 5.56819 6.06819L7.49999 4.13638L9.43179 6.06819C9.60753 6.24392 9.89245 6.24392 10.0682 6.06819C10.2439 5.89245 10.2439 5.60753 10.0682 5.43179L7.81819 3.18179C7.73379 3.0974 7.61933 3.04999 7.49999 3.04999C7.38064 3.04999 7.26618 3.0974 7.18179 3.18179L4.93179 5.43179ZM10.0682 9.56819C10.2439 9.39245 10.2439 9.10753 10.0682 8.93179C9.89245 8.75606 9.60753 8.75606 9.43179 8.93179L7.49999 10.8636L5.56819 8.93179C5.39245 8.75606 5.10753 8.75606 4.93179 8.93179C4.75605 9.10753 4.75605 9.39245 4.93179 9.56819L7.18179 11.8182C7.35753 11.9939 7.64245 11.9939 7.81819 11.8182L10.0682 9.56819Z" fill="currentColor" fill-rule="evenodd">
                  </path>
                 </svg>
                </div>
               </div>
              </div>
             </div>
             <button aria-label="Pause Logs" class="mantine-UnstyledButton-root mantine-ActionIcon-root mantine-152iqvs" type="button">
              <svg class="icon icon-tabler icon-tabler-player-pause" fill="none" height="16" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewbox="0 0 24 24" width="16" xmlns="http://www.w3.org/2000/svg">
               <path d="M0 0h24v24H0z" fill="none" stroke="none">
               </path>
               <rect height="14" rx="1" width="4" x="6" y="5">
               </rect>
               <rect height="14" rx="1" width="4" x="14" y="5">
               </rect>
              </svg>
             </button>
             <button aria-label="Scroll to Top" class="mantine-UnstyledButton-root mantine-ActionIcon-root mantine-152iqvs" type="button">
              <svg class="icon icon-tabler icon-tabler-arrow-up" fill="none" height="16" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewbox="0 0 24 24" width="16" xmlns="http://www.w3.org/2000/svg">
               <path d="M0 0h24v24H0z" fill="none" stroke="none">
               </path>
               <line x1="12" x2="12" y1="5" y2="19">
               </line>
               <line x1="18" x2="12" y1="11" y2="5">
               </line>
               <line x1="6" x2="12" y1="11" y2="5">
               </line>
              </svg>
             </button>
             <button aria-label="Scroll to Bottom" class="mantine-UnstyledButton-root mantine-ActionIcon-root mantine-152iqvs" type="button">
              <svg class="icon icon-tabler icon-tabler-arrow-down" fill="none" height="16" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewbox="0 0 24 24" width="16" xmlns="http://www.w3.org/2000/svg">
               <path d="M0 0h24v24H0z" fill="none" stroke="none">
               </path>
               <line x1="12" x2="12" y1="5" y2="19">
               </line>
               <line x1="18" x2="12" y1="13" y2="19">
               </line>
               <line x1="6" x2="12" y1="13" y2="19">
               </line>
              </svg>
             </button>
            </div>
            <div class="mantine-ButtonGroup-root mantine-n93y9k">
             <button class="mantine-UnstyledButton-root mantine-Button-root mantine-1elrvk9" data-button="true" type="button">
              <div class="mantine-3xbgk5 mantine-Button-inner">
               <span class="mantine-qo1k2 mantine-Button-label">
                Error
               </span>
              </div>
             </button>
             <button class="mantine-UnstyledButton-root mantine-Button-root mantine-1elrvk9" data-button="true" type="button">
              <div class="mantine-3xbgk5 mantine-Button-inner">
               <span class="mantine-qo1k2 mantine-Button-label">
                Warning
               </span>
              </div>
             </button>
             <button class="mantine-UnstyledButton-root mantine-Button-root mantine-1elrvk9" data-button="true" type="button">
              <div class="mantine-3xbgk5 mantine-Button-inner">
               <span class="mantine-qo1k2 mantine-Button-label">
                Info
               </span>
              </div>
             </button>
            </div>
           </div>
          </div>
          <div class="mantine-Divider-root mantine-Divider-horizontal mantine-1lis5e" role="separator">
          </div>
          <div class="mantine-Paper-root mantine-Card-root mantine-1jcn111">
           <table class="mantine-Table-root mantine-145a07o" data-hover="true" data-striped="true">
            <tbody>
             <tr>
             </tr>
            </tbody>
           </table>
          </div>
         </div>
        </div>
       </div>
      </main>
     </div>
    </div>
   </div>
  </div>
  <script id="__NEXT_DATA__" type="application/json">
   {"props":{"pageProps":{}},"page":"/logs","query":{},"buildId":"iiD7YBuGak2wjNaXaNppg","assetPrefix":"/studio","nextExport":true,"autoExport":true,"isFallback":false,"scriptLoader":[]}
  </script>
 </body>
</html>