self.__BUILD_MANIFEST=function(s,a,c){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[a,"static/chunks/113-f20cf828040267fc.js","static/chunks/pages/index-9873ec26aff4396d.js"],"/_error":["static/chunks/pages/_error-8353112a01355ec2.js"],"/actions":[s,a,"static/chunks/3-d801e16fe6466f20.js","static/chunks/pages/actions-23d0ce4e5128707c.js"],"/architype":[s,a,c,"static/chunks/707-69e1edf708a55a15.js","static/chunks/pages/architype-d880a2d3a649d424.js"],"/dashboard":[s,"static/chunks/pages/dashboard-1f7803986fd8e669.js"],"/emotion":["static/chunks/pages/emotion-5c2381ec5367a041.js"],"/graph-viewer":[s,a,"static/chunks/pages/graph-viewer-11af1303610b16aa.js"],"/layout":["static/chunks/pages/layout-8121c21658da9a00.js"],"/logs":[s,c,"static/chunks/30-825cca92eb40c60a.js","static/css/cc49d8d41e055bcd.css","static/chunks/pages/logs-a311b718d668cc55.js"],sortedPages:["/","/_app","/_error","/actions","/architype","/dashboard","/emotion","/graph-viewer","/layout","/logs"]}}("static/chunks/289-4a13cf748d6cfb17.js","static/chunks/76-3f26e2d93951e5cd.js","static/chunks/358-5eea73ebeed3f5bf.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();