{% load static %}
<!DOCTYPE html>
<html>
 <head>
  <meta charset="utf-8"/>
  <title>
   Jaseci Studio
  </title>
  <meta content="minimum-scale=1, initial-scale=1, width=device-width" name="viewport"/>
  <link href="ui_kit/components/components.css" type="text/css"/>
  <meta content="4" name="next-head-count"/>
  <noscript data-n-css="">
  </noscript>
  <script defer="" nomodule="" src='{% static "/studio/_next/static/chunks/polyfills-c67a75d1b6f99dc8.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/webpack-620c68345e03c539.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/framework-3b5a00d5d7e8d93b.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/main-1844b67c68085ff6.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/pages/_app-3023bf5945430c06.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/289-4a13cf748d6cfb17.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/76-3f26e2d93951e5cd.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/358-5eea73ebeed3f5bf.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/707-69e1edf708a55a15.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/pages/architype-d880a2d3a649d424.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/iiD7YBuGak2wjNaXaNppg/_buildManifest.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/iiD7YBuGak2wjNaXaNppg/_ssgManifest.js" %}'>
  </script>
  <style data-emotion="mantine ibbm6b 13jfpqk osix87 hhjyz1 8od8ev p7xtuc 1h8zs6q hv1yhu 1l34ikq khtkeg 11q5icf 14fpfx2 1o9zy70 zf12j9 3xbgk5 qo1k2 69vjwn 6j7erx 1vm4dsg 1n25hpt q1zkt0 1s8spa1 1lis5e 1j6r4wy ngdamr 12o4rl6 1dkv5kp pcb9km 1wvsdi7 11eb7y rbbj0h 137kca9 1avyp1d gyncl 1jftnom nyw25r 1hfjdaf o8x4z2 14swocp 1bkqg0k um9jxx 1s9rvpg 1m3pqry ittua2 12sbrde 265hdg 180iq9w 33vjzt r7pni9 15e18iv ze06i1 1jc5t4g q1fxpn 775zd8 g0only uquezq 18jy38z 1bjr02m 1ynez2c 1ekl79i 6wburq 1jvugyc 11jfaka 1e8ljqt 26ugy1 qvatf7 xlwgkm 1j1ni8n">
   .mantine-ibbm6b{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;box-sizing:border-box;}.mantine-13jfpqk{-webkit-flex:1;-ms-flex:1;flex:1;width:100vw;box-sizing:border-box;min-height:100vh;padding-top:calc(var(--mantine-header-height, 0px) + 16px);padding-bottom:calc(var(--mantine-footer-height, 0px) + 16px);padding-left:calc(var(--mantine-navbar-width, 0px) + 16px);padding-right:calc(var(--mantine-aside-width, 0px) + 16px);}@media (max-width: -1px){.mantine-13jfpqk{padding-right:16px;}}.mantine-osix87{box-sizing:border-box;}.mantine-hhjyz1{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;top:var(--mantine-header-height);left:0;bottom:0;z-index:100;height:100vh;width:80px;position:fixed;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;background-color:#fff;border-right:1px solid #e9ecef;padding:16px;}@media (max-width: 991px){.mantine-hhjyz1[data-hidden]{display:none;}}.mantine-8od8ev{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;}.mantine-p7xtuc{margin-top:50px;-webkit-flex:1;-ms-flex:1;flex:1;box-sizing:border-box;}.mantine-1h8zs6q{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;gap:0;}.mantine-hv1yhu{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;width:50px;height:50px;border-radius:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;color:#495057;}.mantine-hv1yhu:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-hv1yhu:focus:not(:focus-visible){outline:none;}.mantine-hv1yhu:hover{background-color:#f8f9fa;}.mantine-1l34ikq{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;width:50px;height:50px;border-radius:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;color:#495057;}.mantine-1l34ikq:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1l34ikq:focus:not(:focus-visible){outline:none;}.mantine-1l34ikq:hover{background-color:#f8f9fa;}.mantine-1l34ikq,.mantine-1l34ikq:hover{background-color:rgba(255, 244, 230, 1);color:#fd7e14;}.mantine-khtkeg{-webkit-flex:0;-ms-flex:0;flex:0;box-sizing:border-box;}.mantine-11q5icf{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;}.mantine-14fpfx2{outline:0;-webkit-tap-highlight-color:transparent;display:block;-webkit-text-decoration:none;text-decoration:none;color:#000;background-color:#fff;box-sizing:border-box;border-radius:8px;box-shadow:0 1px 3px rgba(0, 0, 0, 0.05),rgba(0, 0, 0, 0.05) 0px 20px 25px -5px,rgba(0, 0, 0, 0.04) 0px 10px 10px -5px;border:1px solid #dee2e6;position:relative;overflow:hidden;background-color:#fff;margin:0 auto;overflow-y:scroll;padding:30px;width:90%;height:90vh;}.mantine-1o9zy70{box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;-webkit-align-items:start;-webkit-box-align:start;-ms-flex-align:start;align-items:start;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;justify-content:space-between;gap:16px;}.mantine-1o9zy70>*{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;}.mantine-zf12j9{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;color:inherit;font-size:inherit;line-height:1.55;-webkit-text-decoration:none;text-decoration:none;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;font-weight:700;font-size:22px;line-height:1.4;margin:0;margin-bottom:24px;}.mantine-zf12j9:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-zf12j9:focus:not(:focus-visible){outline:none;}.mantine-3xbgk5{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;height:100%;overflow:visible;}.mantine-qo1k2{white-space:nowrap;height:100%;overflow:hidden;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;}.mantine-69vjwn{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;height:36px;padding-left:18px;padding-right:18px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;display:inline-block;width:auto;border-radius:4px;font-weight:600;position:relative;line-height:1;font-size:14px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;border:1px solid transparent;background-color:#fd7e14;color:#fff;}.mantine-69vjwn:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-69vjwn:focus:not(:focus-visible){outline:none;}.mantine-69vjwn:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-69vjwn:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-69vjwn:hover{background-color:#f76707;}}@media (hover: none){.mantine-69vjwn:active{background-color:#f76707;}}.mantine-69vjwn:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-69vjwn:disabled,.mantine-69vjwn[data-disabled]{border-color:transparent;background-color:#e9ecef;color:#adb5bd;cursor:not-allowed;background-image:none;pointer-events:none;}.mantine-69vjwn:disabled:active,.mantine-69vjwn[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-69vjwn[data-loading]{pointer-events:none;}.mantine-69vjwn[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}.mantine-6j7erx{margin:-8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:start;-ms-flex-pack:start;-webkit-justify-content:flex-start;justify-content:flex-start;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;height:600px;}.mantine-1vm4dsg{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;padding:8px;-webkit-flex-basis:41.66666666666667%;-ms-flex-preferred-size:41.66666666666667%;flex-basis:41.66666666666667%;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;max-width:41.66666666666667%;}@media (min-width: 576px){.mantine-1vm4dsg{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 768px){.mantine-1vm4dsg{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 992px){.mantine-1vm4dsg{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1200px){.mantine-1vm4dsg{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1400px){.mantine-1vm4dsg{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}.mantine-1n25hpt{width:100%;height:100%;overflow-y:auto;background:#f5f5f5;padding-right:16px;padding-left:16px;padding-top:16px;padding-bottom:16px;}.mantine-q1zkt0{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;color:inherit;font-size:inherit;line-height:1.55;-webkit-text-decoration:none;text-decoration:none;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;font-weight:700;font-size:16px;line-height:1.5;margin:0;margin-bottom:16px;}.mantine-q1zkt0:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-q1zkt0:focus:not(:focus-visible){outline:none;}.mantine-1lis5e{border:0;border-top-width:1px;border-top-color:#ced4da;border-top-style:solid;margin:0;}.mantine-1j6r4wy{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;border-radius:4px;font-weight:500;font-size:14px;cursor:pointer;display:block;text-align:center;padding:5px 10px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#495057;-webkit-transition:color 0ms ease;transition:color 0ms ease;}.mantine-1j6r4wy:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1j6r4wy:focus:not(:focus-visible){outline:none;}.mantine-1j6r4wy:hover{color:#000;}.mantine-ngdamr{position:relative;box-sizing:border-box;-webkit-flex:1;-ms-flex:1;flex:1;z-index:2;-webkit-transition:border-left-color 0ms ease;transition:border-left-color 0ms ease;}.mantine-ngdamr:not(:first-of-type){border-style:solid;border-width:0 0 0 1px;border-color:#dee2e6;}.mantine-12o4rl6{height:0;width:0;position:absolute;overflow:hidden;white-space:nowrap;opacity:0;}.mantine-12o4rl6:focus{outline:none;}.mantine-12o4rl6:focus+.__mantine-ref-label{outline-offset:2px;outline:2px solid #ff922b;}.mantine-12o4rl6:focus:focus:not(:focus-visible)+.__mantine-ref-label{outline:none;}.mantine-1dkv5kp{position:relative;box-sizing:border-box;-webkit-flex:1;-ms-flex:1;flex:1;z-index:2;-webkit-transition:border-left-color 0ms ease;transition:border-left-color 0ms ease;border-left-color:transparent!important;border-top-color:transparent!important;border-radius:4px;box-shadow:0 1px 3px rgba(0, 0, 0, 0.05),0 1px 2px rgba(0, 0, 0, 0.1);background-color:#fff;}.mantine-1dkv5kp:not(:first-of-type){border-style:solid;border-width:0 0 0 1px;border-color:#dee2e6;}.mantine-1dkv5kp+.__mantine-ref-control{border-left-color:transparent!important;border-top-color:transparent!important;}.mantine-pcb9km{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;border-radius:4px;font-weight:500;font-size:14px;cursor:pointer;display:block;text-align:center;padding:5px 10px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#495057;-webkit-transition:color 0ms ease;transition:color 0ms ease;}.mantine-pcb9km:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-pcb9km:focus:not(:focus-visible){outline:none;}.mantine-pcb9km:hover{color:#000;}.mantine-pcb9km,.mantine-pcb9km:hover{color:#000;}.mantine-1wvsdi7{position:relative;display:-webkit-inline-box;display:-webkit-inline-flex;display:-ms-inline-flexbox;display:inline-flex;width:auto;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;background-color:#f1f3f5;border-radius:4px;overflow:hidden;padding:4px;}.mantine-11eb7y{border:0;border-top-width:1px;border-top-color:#ced4da;border-top-style:solid;margin:0;margin-bottom:16px;}.mantine-rbbj0h{overflow:scroll;height:500px;position:relative;}.mantine-137kca9{position:absolute;top:0;left:0;right:0;bottom:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;overflow:hidden;}.mantine-gyncl{position:absolute;top:0;bottom:0;left:0;right:0;z-index:400;background-color:#fff;opacity:0.75;border-radius:0;}.mantine-1jftnom{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;-webkit-box-pack:top;-ms-flex-pack:top;-webkit-justify-content:top;justify-content:top;gap:16px;padding:10px;}.mantine-nyw25r{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;padding:8px;-webkit-flex-basis:58.333333333333336%;-ms-flex-preferred-size:58.333333333333336%;flex-basis:58.333333333333336%;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;max-width:58.333333333333336%;}@media (min-width: 576px){.mantine-nyw25r{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 768px){.mantine-nyw25r{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 992px){.mantine-nyw25r{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1200px){.mantine-nyw25r{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1400px){.mantine-nyw25r{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}.mantine-1hfjdaf{-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;}.mantine-o8x4z2{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:start;-ms-flex-pack:start;-webkit-justify-content:flex-start;justify-content:flex-start;border-bottom:2px solid #dee2e6;}.mantine-14swocp{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;}.mantine-14swocp:not(:only-child){margin-right:7px;}.mantine-1bkqg0k{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;position:relative;padding:10px 16px;padding-left:10px;font-size:14px;white-space:nowrap;z-index:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;line-height:1;border-bottom:2px solid transparent;margin-bottom:-2px;border-radius:4px 4px 0 0;}.mantine-1bkqg0k:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1bkqg0k:focus:not(:focus-visible){outline:none;}.mantine-1bkqg0k:disabled{opacity:0.5;cursor:not-allowed;}@media (hover: hover){.mantine-1bkqg0k:disabled:hover{background-color:transparent;}}@media (hover: none){.mantine-1bkqg0k:disabled:active{background-color:transparent;}}.mantine-1bkqg0k:focus{z-index:1;}@media (hover: hover){.mantine-1bkqg0k:hover{background-color:#f8f9fa;border-color:#dee2e6;}}@media (hover: none){.mantine-1bkqg0k:active{background-color:#f8f9fa;border-color:#dee2e6;}}.mantine-1bkqg0k[data-active]{border-color:#fd7e14;color:#000;}@media (hover: hover){.mantine-1bkqg0k[data-active]:hover{border-color:#fd7e14;}}@media (hover: none){.mantine-1bkqg0k[data-active]:active{border-color:#fd7e14;}}.mantine-um9jxx{padding-top:10px;}.mantine-1s9rvpg{padding-top:10px;display:none;height:100%;}.mantine-1m3pqry{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;line-height:1.55;}.mantine-ittua2{display:inline-block;font-size:14px;font-weight:500;color:#212529;word-break:break-word;cursor:default;-webkit-tap-highlight-color:transparent;}.mantine-12sbrde{position:relative;}.mantine-265hdg{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;height:auto;-webkit-tap-highlight-color:transparent;line-height:1.55;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;resize:none;box-sizing:border-box;font-size:14px;width:100%;color:#000;display:block;text-align:left;min-height:36px;padding-left:12px;padding-right:12px;border-radius:4px;border:1px solid #ced4da;background-color:#fff;-webkit-transition:border-color 100ms ease;transition:border-color 100ms ease;padding-top:10px;padding-bottom:10px;font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace;font-size:12px;}.mantine-265hdg:disabled{background-color:#f1f3f5;color:#909296;opacity:0.6;cursor:not-allowed;}.mantine-265hdg:disabled::-webkit-input-placeholder{color:#909296;}.mantine-265hdg:disabled::-moz-placeholder{color:#909296;}.mantine-265hdg:disabled:-ms-input-placeholder{color:#909296;}.mantine-265hdg:disabled::placeholder{color:#909296;}.mantine-265hdg::-webkit-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-265hdg::-moz-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-265hdg:-ms-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-265hdg::placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-265hdg::-webkit-inner-spin-button,.mantine-265hdg::-webkit-outer-spin-button,.mantine-265hdg::-webkit-search-decoration,.mantine-265hdg::-webkit-search-cancel-button,.mantine-265hdg::-webkit-search-results-button,.mantine-265hdg::-webkit-search-results-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}.mantine-265hdg[type=number]{-moz-appearance:textfield;}.mantine-265hdg:focus,.mantine-265hdg:focus-within{outline:none;border-color:#fd7e14;}.mantine-180iq9w{color:#fff;-webkit-transform:translateY(5px) scale(0.5);-moz-transform:translateY(5px) scale(0.5);-ms-transform:translateY(5px) scale(0.5);transform:translateY(5px) scale(0.5);opacity:0;transition-property:opacity,transform;transition-timing-function:ease;transition-duration:100ms;pointer-events:none;width:10px;position:absolute;z-index:1;top:0;bottom:0;left:0;right:0;margin:auto;}@media (prefers-reduced-motion){.mantine-180iq9w{transition-duration:0ms;}}.mantine-33vjzt{position:relative;width:20px;height:20px;-webkit-order:1;-ms-flex-order:1;order:1;}.mantine-r7pni9{-webkit-tap-highlight-color:transparent;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;background-color:#fff;border:1px solid #ced4da;width:20px;height:20px;border-radius:4px;padding:0;display:block;margin:0;-webkit-transition:border-color 100ms ease,background-color 100ms ease;transition:border-color 100ms ease,background-color 100ms ease;cursor:default;}.mantine-r7pni9:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-r7pni9:focus:not(:focus-visible){outline:none;}.mantine-r7pni9:checked{background-color:#fd7e14;border-color:#fd7e14;}.mantine-r7pni9:checked+.__mantine-ref-icon{opacity:1;color:#fff;-webkit-transform:translateY(0) scale(1);-moz-transform:translateY(0) scale(1);-ms-transform:translateY(0) scale(1);transform:translateY(0) scale(1);}.mantine-r7pni9:disabled{background-color:#e9ecef;border-color:#dee2e6;cursor:not-allowed;}.mantine-r7pni9:disabled+.__mantine-ref-icon{color:#adb5bd;}.mantine-15e18iv{display:-webkit-inline-box;display:-webkit-inline-flex;display:-ms-inline-flexbox;display:inline-flex;}.mantine-ze06i1{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;font-size:14px;line-height:20px;color:#000;cursor:default;-webkit-order:2;-ms-flex-order:2;order:2;}.mantine-1jc5t4g{cursor:default;padding-left:12px;}.mantine-1jc5t4g[data-disabled]{color:#adb5bd;}.mantine-q1fxpn{margin-top:12px;margin-bottom:12px;}.mantine-775zd8{box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;justify-content:space-between;gap:16px;margin-top:12px;margin-bottom:12px;}.mantine-775zd8>*{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;}.mantine-g0only{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;line-height:1.55;min-width:300px;}.mantine-uquezq{position:absolute;top:0;bottom:0;right:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;width:30px;pointer-events:none;}.mantine-18jy38z{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;height:36px;-webkit-tap-highlight-color:transparent;line-height:34px;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;resize:none;box-sizing:border-box;font-size:14px;width:100%;color:#000;display:block;text-align:left;min-height:36px;padding-left:12px;padding-right:30px;border-radius:4px;border:1px solid #ced4da;background-color:#fff;-webkit-transition:border-color 100ms ease;transition:border-color 100ms ease;}.mantine-18jy38z:disabled{background-color:#f1f3f5;color:#909296;opacity:0.6;cursor:not-allowed;}.mantine-18jy38z:disabled::-webkit-input-placeholder{color:#909296;}.mantine-18jy38z:disabled::-moz-placeholder{color:#909296;}.mantine-18jy38z:disabled:-ms-input-placeholder{color:#909296;}.mantine-18jy38z:disabled::placeholder{color:#909296;}.mantine-18jy38z::-webkit-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-18jy38z::-moz-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-18jy38z:-ms-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-18jy38z::placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-18jy38z::-webkit-inner-spin-button,.mantine-18jy38z::-webkit-outer-spin-button,.mantine-18jy38z::-webkit-search-decoration,.mantine-18jy38z::-webkit-search-cancel-button,.mantine-18jy38z::-webkit-search-results-button,.mantine-18jy38z::-webkit-search-results-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}.mantine-18jy38z[type=number]{-moz-appearance:textfield;}.mantine-18jy38z:focus,.mantine-18jy38z:focus-within{outline:none;border-color:#fd7e14;}.mantine-1bjr02m{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;height:30px;padding-left:14px;padding-right:14px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;display:inline-block;width:auto;border-radius:4px;font-weight:600;position:relative;line-height:1;font-size:12px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;border:1px solid transparent;background-color:#12b886;color:#fff;margin-top:16px;}.mantine-1bjr02m:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1bjr02m:focus:not(:focus-visible){outline:none;}.mantine-1bjr02m:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1bjr02m:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-1bjr02m:hover{background-color:#0ca678;}}@media (hover: none){.mantine-1bjr02m:active{background-color:#0ca678;}}.mantine-1bjr02m:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-1bjr02m:disabled,.mantine-1bjr02m[data-disabled]{border-color:transparent;background-color:#e9ecef;color:#adb5bd;cursor:not-allowed;background-image:none;pointer-events:none;}.mantine-1bjr02m:disabled:active,.mantine-1bjr02m[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-1bjr02m[data-loading]{pointer-events:none;}.mantine-1bjr02m[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}.mantine-1ynez2c{background:#e9ecef;border:#adb5bd;border-radius:8px;min-height:300px;max-height:400px;overflow-y:scroll;margin-top:20px;margin-bottom:20px;padding-right:16px;padding-left:16px;padding-top:10px;padding-bottom:10px;}.mantine-1ekl79i{box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:row;-ms-flex-direction:row;flex-direction:row;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:start;-ms-flex-pack:start;-webkit-justify-content:flex-start;justify-content:flex-start;gap:10px;margin-bottom:12px;}.mantine-1ekl79i>*{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;}.mantine-6wburq{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;color:inherit;font-size:inherit;line-height:1.55;-webkit-text-decoration:none;text-decoration:none;font-weight:bold;}.mantine-6wburq:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-6wburq:focus:not(:focus-visible){outline:none;}.mantine-1jvugyc{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;display:-webkit-inline-box;display:-webkit-inline-flex;display:-ms-inline-flexbox;display:inline-flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;box-sizing:border-box;width:20px;height:20px;min-width:20px;min-height:20px;border-radius:32px;background-color:#fa5252;color:#fff;border:1px solid transparent;}.mantine-11jfaka{box-sizing:border-box;position:relative;font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace;line-height:1.7;font-size:13px;border-radius:4px;padding:12px 0;margin-top:0;margin-bottom:0;}.mantine-1e8ljqt{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;width:100%;padding:0 16px;}.mantine-26ugy1{width:100%;}.mantine-qvatf7{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;border:1px solid transparent;background-color:transparent;color:#868e96;position:relative;height:28px;min-height:28px;width:28px;min-width:28px;border-radius:4px;padding:0;line-height:1;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;position:absolute;top:10px;right:10px;left:unset;z-index:2;}.mantine-qvatf7:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-qvatf7:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-qvatf7:hover{background-color:rgba(248, 249, 250, 1);}}@media (hover: none){.mantine-qvatf7:active{background-color:rgba(248, 249, 250, 1);}}.mantine-qvatf7:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-qvatf7:disabled,.mantine-qvatf7[data-disabled]{color:#ced4da;cursor:not-allowed;background-color:#f1f3f5;border-color:#f1f3f5;background-image:none;pointer-events:none;}.mantine-qvatf7:disabled:active,.mantine-qvatf7[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-qvatf7[data-loading]{pointer-events:none;}.mantine-qvatf7[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}.mantine-qvatf7,.mantine-qvatf7:hover{background-color:#f8f9fa;}.mantine-xlwgkm{width:100%;height:100%;}.mantine-1j1ni8n{overflow:hidden;}
  </style>
  <script>
   window.django = {is_authenticated: "{{ request.user.is_authenticated }}" === "True" ? true : false, user: "{{request.user}}"};
  </script>
 </head>
 <body>
  <div id="__next">
   <script src='{% static "/studio/ui_kit/components/components.esm.js" %}' type="module">
   </script>
   <script nomodule="" src='{% static "/studio/ui_kit/components/components.js" %}'>
   </script>
   <style data-emotion="css-global zl4edr">
    html{font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%;-ms-text-size-adjust:100%;text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section,figcaption,figure,main{display:block;}h1{font-size:2em;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background:transparent;text-decoration-skip:objects;}a:active,a:hover{outline-width:0;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;}b,strong{font-weight:bolder;}code,kbp,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sup{top:-0.5em;}sub{bottom:-0.25em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;vertical-align:middle;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,[type=reset],[type=submit]{-webkit-appearance:button;}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=checkbox],[type=radio]{box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto;}[type=search]{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}[type=search]::-webkit-search-cancel-button,[type=search]::-webkit-search-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;-moz-appearance:button;-ms-appearance:button;appearance:button;font:inherit;}details,menu{display:block;}summary{display:-webkit-box;display:-webkit-list-item;display:-ms-list-itembox;display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}
   </style>
   <style data-emotion="css-global 1j3c5om">
    *,*::before,*::after{box-sizing:border-box;}html{-webkit-print-color-scheme:light;color-scheme:light;}body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;background-color:#fff;color:#000;line-height:1.55;font-size:16px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;}
   </style>
   <style data-emotion="css-global wo6pb2">
   </style>
   <div data-theme="greenheart">
    <div class="mantine-AppShell-root mantine-osix87">
     <div class="mantine-ibbm6b mantine-AppShell-body">
      <nav class="mantine-Navbar-root mantine-hhjyz1">
       <div class="mantine-8od8ev">
        <img alt="Jaseci Logo" height="42" src="/static/studio/Jaseci-Submark.png" width="40"/>
       </div>
       <div class="mantine-p7xtuc">
        <div class="mantine-Stack-root mantine-1h8zs6q">
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-home-2" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="5 12 3 12 12 3 21 12 19 12">
           </polyline>
           <path d="M5 12v7a2 2 0 0 0 2 2h10a2 2 0 0 0 2 -2v-7">
           </path>
           <rect height="4" width="4" x="10" y="12">
           </rect>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-gauge" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <circle cx="12" cy="12" r="9">
           </circle>
           <circle cx="12" cy="12" r="1">
           </circle>
           <line x1="13.41" x2="16" y1="10.59" y2="8">
           </line>
           <path d="M7 12a5 5 0 0 1 5 -5">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-vector-bezier-circle" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <rect height="4" rx="1" width="4" x="3" y="10">
           </rect>
           <rect height="4" rx="1" width="4" x="17" y="10">
           </rect>
           <rect height="4" rx="1" width="4" x="10" y="3">
           </rect>
           <rect height="4" rx="1" width="4" x="10" y="17">
           </rect>
           <path d="M19 10a5 5 0 0 0 -5 -5">
           </path>
           <path d="M19 14a5 5 0 0 1 -5 5">
           </path>
           <path d="M5 14a5 5 0 0 0 5 5">
           </path>
           <path d="M5 10a5 5 0 0 1 5 -5">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-prompt" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="5 7 10 12 5 17">
           </polyline>
           <line x1="13" x2="19" y1="17" y2="17">
           </line>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-server-bolt" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <rect height="8" rx="3" width="18" x="3" y="4">
           </rect>
           <path d="M15 20h-9a3 3 0 0 1 -3 -3v-2a3 3 0 0 1 3 -3h12">
           </path>
           <path d="M7 8v.01">
           </path>
           <path d="M7 16v.01">
           </path>
           <path d="M20 15l-2 3h3l-2 3">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-1l34ikq" type="button">
          <svg class="icon icon-tabler icon-tabler-code" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="7 8 3 12 7 16">
           </polyline>
           <polyline points="17 8 21 12 17 16">
           </polyline>
           <line x1="14" x2="10" y1="4" y2="20">
           </line>
          </svg>
         </button>
        </div>
       </div>
       <div class="mantine-khtkeg">
        <div class="mantine-Stack-root mantine-1h8zs6q">
        </div>
       </div>
       <style data-emotion="css-global 563mdc">
        :root{--mantine-navbar-width:80px;}
       </style>
      </nav>
      <main class="mantine-13jfpqk mantine-AppShell-main">
       <div>
        <div class="mantine-11q5icf">
         <div class="mantine-Paper-root mantine-Card-root mantine-14fpfx2">
          <div class="mantine-Group-root mantine-1o9zy70">
           <h3 class="mantine-Text-root mantine-Title-root mantine-zf12j9">
            Architypes
           </h3>
           <button class="mantine-UnstyledButton-root mantine-Button-root mantine-69vjwn" data-button="true" data-disabled="true" disabled="" type="button">
            <div class="mantine-3xbgk5 mantine-Button-inner">
             <span class="mantine-qo1k2 mantine-Button-label">
              Register Architype
             </span>
            </div>
           </button>
          </div>
          <div class="mantine-Grid-root mantine-6j7erx">
           <div class="mantine-Col-root mantine-1vm4dsg">
            <div class="mantine-1n25hpt">
             <h5 class="mantine-Text-root mantine-Title-root mantine-q1zkt0">
              All Architypes
             </h5>
             <div class="mantine-Divider-root mantine-Divider-horizontal mantine-1lis5e" role="separator">
             </div>
             <div class="mantine-SegmentedControl-root mantine-1wvsdi7">
              <div class="__mantine-ref-control mantine-SegmentedControl-control mantine-SegmentedControl-controlActive mantine-1dkv5kp">
               <input checked="" class="mantine-12o4rl6 mantine-SegmentedControl-input" id="mantine-Rdlam6-all" name="mantine-Rdlam6" type="radio" value="all"/>
               <label class="__mantine-ref-label mantine-SegmentedControl-label mantine-SegmentedControl-labelActive mantine-pcb9km" for="mantine-Rdlam6-all">
                All
               </label>
              </div>
              <div class="__mantine-ref-control mantine-ngdamr mantine-SegmentedControl-control">
               <input class="mantine-12o4rl6 mantine-SegmentedControl-input" id="mantine-Rdlam6-node" name="mantine-Rdlam6" type="radio" value="node"/>
               <label class="__mantine-ref-label mantine-1j6r4wy mantine-SegmentedControl-label" for="mantine-Rdlam6-node">
                Nodes
               </label>
              </div>
              <div class="__mantine-ref-control mantine-ngdamr mantine-SegmentedControl-control">
               <input class="mantine-12o4rl6 mantine-SegmentedControl-input" id="mantine-Rdlam6-walker" name="mantine-Rdlam6" type="radio" value="walker"/>
               <label class="__mantine-ref-label mantine-1j6r4wy mantine-SegmentedControl-label" for="mantine-Rdlam6-walker">
                Walkers
               </label>
              </div>
              <div class="__mantine-ref-control mantine-ngdamr mantine-SegmentedControl-control">
               <input class="mantine-12o4rl6 mantine-SegmentedControl-input" id="mantine-Rdlam6-edge" name="mantine-Rdlam6" type="radio" value="edge"/>
               <label class="__mantine-ref-label mantine-1j6r4wy mantine-SegmentedControl-label" for="mantine-Rdlam6-edge">
                Edges
               </label>
              </div>
             </div>
             <div class="mantine-Divider-root mantine-Divider-horizontal mantine-11eb7y" role="separator">
             </div>
             <div class="mantine-rbbj0h">
              <div class="mantine-LoadingOverlay-root mantine-137kca9" style="z-index:400">
               <svg class="mantine-1avyp1d" height="36px" role="presentation" stroke="#fd7e14" style="z-index:calc(400 + 1)" viewbox="0 0 38 38" width="36px" xmlns="http://www.w3.org/2000/svg">
                <g fill="none" fill-rule="evenodd">
                 <g stroke-width="5" transform="translate(2.5 2.5)">
                  <circle cx="16" cy="16" r="16" stroke-opacity=".5">
                  </circle>
                  <path d="M32 16c0-9.94-8.06-16-16-16">
                   <animatetransform attributename="transform" dur="1s" from="0 16 16" repeatcount="indefinite" to="360 16 16" type="rotate">
                   </animatetransform>
                  </path>
                 </g>
                </g>
               </svg>
               <div class="mantine-Overlay-root mantine-gyncl">
               </div>
              </div>
              <div class="mantine-Stack-root mantine-1jftnom" data-testid="architype-cards">
              </div>
             </div>
            </div>
           </div>
           <div class="mantine-Col-root mantine-nyw25r">
            <div class="mantine-Tabs-root mantine-1hfjdaf">
             <div aria-orientation="horizontal" class="mantine-Tabs-tabsList mantine-o8x4z2" role="tablist">
              <button aria-controls="mantine-R2lam6-panel-editor" aria-selected="true" class="mantine-UnstyledButton-root mantine-Tabs-tab mantine-1bkqg0k" data-active="true" id="mantine-R2lam6-tab-editor" role="tab" tabindex="0" type="button">
               <div class="mantine-14swocp mantine-Tabs-tabIcon">
                <svg class="icon icon-tabler icon-tabler-brackets" fill="none" height="14" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewbox="0 0 24 24" width="14" xmlns="http://www.w3.org/2000/svg">
                 <path d="M0 0h24v24H0z" fill="none" stroke="none">
                 </path>
                 <path d="M8 4h-3v16h3">
                 </path>
                 <path d="M16 4h3v16h-3">
                 </path>
                </svg>
               </div>
               <div class="mantine-1s8spa1 mantine-Tabs-tabLabel">
                Editor
               </div>
              </button>
              <button aria-controls="mantine-R2lam6-panel-run_walker" aria-selected="false" class="mantine-UnstyledButton-root mantine-Tabs-tab mantine-1bkqg0k" id="mantine-R2lam6-tab-run_walker" role="tab" tabindex="-1" type="button">
               <div class="mantine-14swocp mantine-Tabs-tabIcon">
                <svg class="icon icon-tabler icon-tabler-api" fill="none" height="14" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewbox="0 0 24 24" width="14" xmlns="http://www.w3.org/2000/svg">
                 <path d="M0 0h24v24H0z" fill="none" stroke="none">
                 </path>
                 <path d="M4 13h5">
                 </path>
                 <path d="M12 16v-8h3a2 2 0 0 1 2 2v1a2 2 0 0 1 -2 2h-3">
                 </path>
                 <path d="M20 8v8">
                 </path>
                 <path d="M9 16v-5.5a2.5 2.5 0 0 0 -5 0v5.5">
                 </path>
                </svg>
               </div>
               <div class="mantine-1s8spa1 mantine-Tabs-tabLabel">
                Run Walker
               </div>
              </button>
             </div>
             <div aria-labelledby="mantine-R2lam6-tab-editor" class="mantine-Tabs-panel mantine-um9jxx" id="mantine-R2lam6-panel-editor" role="tabpanel">
              <section style="display:flex;position:relative;text-align:initial;width:100%;height:600px">
               <div style="display:flex;height:100%;width:100%;justify-content:center;align-items:center">
                Loading...
               </div>
               <div style="width:100%;display:none">
               </div>
              </section>
             </div>
             <div aria-labelledby="mantine-R2lam6-tab-run_walker" class="mantine-Tabs-panel mantine-1s9rvpg" id="mantine-R2lam6-panel-run_walker" role="tabpanel">
              <div>
               <div class="mantine-InputWrapper-root mantine-JsonInput-root mantine-1m3pqry">
                <label class="mantine-InputWrapper-label mantine-JsonInput-label mantine-ittua2" for="mantine-R1ulam6" id="mantine-R1ulam6-label">
                 Enter Payload
                </label>
                <div class="mantine-Input-wrapper mantine-JsonInput-wrapper mantine-12sbrde">
                 <textarea aria-invalid="false" autocapitalize="off" autocomplete="off" autocorrect="off" class="mantine-JsonInput-input mantine-Input-input mantine-JsonInput-input mantine-265hdg" id="mantine-R1ulam6" placeholder="Enter payload to run walker">{}</textarea>
                </div>
               </div>
               <div class="mantine-Checkbox-root mantine-q1fxpn">
                <div class="mantine-15e18iv mantine-Checkbox-body">
                 <div class="mantine-33vjzt mantine-Checkbox-inner">
                  <input class="mantine-r7pni9 mantine-Checkbox-input" id="mantine-R2ulam6" type="checkbox"/>
                  <svg class="__mantine-ref-icon mantine-180iq9w mantine-Checkbox-icon" fill="none" viewbox="0 0 10 7" xmlns="http://www.w3.org/2000/svg">
                   <path clip-rule="evenodd" d="M4 4.586L1.707 2.293A1 1 0 1 0 .293 3.707l3 3a.997.997 0 0 0 1.414 0l5-5A1 1 0 1 0 8.293.293L4 4.586z" fill="currentColor" fill-rule="evenodd">
                   </path>
                  </svg>
                 </div>
                 <div class="mantine-ze06i1 mantine-Checkbox-labelWrapper">
                  <label class="mantine-1jc5t4g mantine-Checkbox-label" for="mantine-R2ulam6">
                   Run on node
                  </label>
                 </div>
                </div>
               </div>
               <div class="mantine-Group-root mantine-775zd8">
                <div class="mantine-InputWrapper-root mantine-Select-root mantine-g0only">
                 <label class="mantine-InputWrapper-label mantine-Select-label mantine-ittua2" for="mantine-Rculam6" id="mantine-Rculam6-label">
                  Walker
                 </label>
                 <div aria-controls="mantine-Rculam6" aria-expanded="false" aria-haspopup="listbox" class="" role="combobox" tabindex="-1">
                  <input type="hidden" value=""/>
                  <div class="mantine-Input-wrapper mantine-Select-wrapper mantine-12sbrde">
                   <input aria-autocomplete="list" aria-invalid="false" autocomplete="off" class="mantine-Input-input mantine-Select-input mantine-18jy38z" data-mantine-stop-propagation="false" data-testid="walker-select" id="mantine-Rculam6" placeholder="Pick a walker to run" type="search" value=""/>
                   <div class="mantine-uquezq mantine-Input-rightSection mantine-Select-rightSection">
                    <svg data-chevron="true" fill="none" height="18" style="color:#868e96" viewbox="0 0 15 15" width="18" xmlns="http://www.w3.org/2000/svg">
                     <path clip-rule="evenodd" d="M4.93179 5.43179C4.75605 5.60753 4.75605 5.89245 4.93179 6.06819C5.10753 6.24392 5.39245 6.24392 5.56819 6.06819L7.49999 4.13638L9.43179 6.06819C9.60753 6.24392 9.89245 6.24392 10.0682 6.06819C10.2439 5.89245 10.2439 5.60753 10.0682 5.43179L7.81819 3.18179C7.73379 3.0974 7.61933 3.04999 7.49999 3.04999C7.38064 3.04999 7.26618 3.0974 7.18179 3.18179L4.93179 5.43179ZM10.0682 9.56819C10.2439 9.39245 10.2439 9.10753 10.0682 8.93179C9.89245 8.75606 9.60753 8.75606 9.43179 8.93179L7.49999 10.8636L5.56819 8.93179C5.39245 8.75606 5.10753 8.75606 4.93179 8.93179C4.75605 9.10753 4.75605 9.39245 4.93179 9.56819L7.18179 11.8182C7.35753 11.9939 7.64245 11.9939 7.81819 11.8182L10.0682 9.56819Z" fill="currentColor" fill-rule="evenodd">
                     </path>
                    </svg>
                   </div>
                  </div>
                 </div>
                </div>
                <button class="mantine-UnstyledButton-root mantine-Button-root mantine-1bjr02m" data-button="true" data-disabled="true" disabled="" type="button">
                 <div class="mantine-3xbgk5 mantine-Button-inner">
                  <span class="mantine-qo1k2 mantine-Button-label">
                   Run Now
                  </span>
                 </div>
                </button>
               </div>
               <div class="mantine-1ynez2c" data-testid="result">
                <div class="mantine-Group-root mantine-1ekl79i">
                 <div class="mantine-Text-root mantine-6wburq">
                  Result
                 </div>
                 <div class="mantine-ThemeIcon-root mantine-1jvugyc">
                  <svg class="icon icon-tabler icon-tabler-shield-x" fill="none" height="14" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewbox="0 0 24 24" width="14" xmlns="http://www.w3.org/2000/svg">
                   <path d="M0 0h24v24H0z" fill="none" stroke="none">
                   </path>
                   <path d="M12 3a12 12 0 0 0 8.5 3a12 12 0 0 1 -8.5 15a12 12 0 0 1 -8.5 -15a12 12 0 0 0 8.5 -3">
                   </path>
                   <path d="M10 10l4 4m0 -4l-4 4">
                   </path>
                  </svg>
                 </div>
                </div>
                <div class="mantine-Divider-root mantine-Divider-horizontal mantine-1lis5e" role="separator">
                </div>
                <div class="mantine-Prism-root mantine-12sbrde" translate="no">
                 <button aria-label="Copy code" class="mantine-UnstyledButton-root mantine-ActionIcon-root mantine-Prism-copy mantine-qvatf7" type="button">
                  <svg fill="none" height="15" viewbox="0 0 15 15" width="15" xmlns="http://www.w3.org/2000/svg">
                   <path clip-rule="evenodd" d="M5 2V1H10V2H5ZM4.75 0C4.33579 0 4 0.335786 4 0.75V1H3.5C2.67157 1 2 1.67157 2 2.5V12.5C2 13.3284 2.67157 14 3.5 14H11.5C12.3284 14 13 13.3284 13 12.5V2.5C13 1.67157 12.3284 1 11.5 1H11V0.75C11 0.335786 10.6642 0 10.25 0H4.75ZM11 2V2.25C11 2.66421 10.6642 3 10.25 3H4.75C4.33579 3 4 2.66421 4 2.25V2H3.5C3.22386 2 3 2.22386 3 2.5V12.5C3 12.7761 3.22386 13 3.5 13H11.5C11.7761 13 12 12.7761 12 12.5V2.5C12 2.22386 11.7761 2 11.5 2H11Z" fill="currentColor" fill-rule="evenodd">
                   </path>
                  </svg>
                 </button>
                 <div class="mantine-ScrollArea-root mantine-Prism-scrollArea mantine-1j1ni8n" dir="ltr" style="position:relative;--radix-scroll-area-corner-width:0px;--radix-scroll-area-corner-height:0px">
                  <style>
                   [data-radix-scroll-area-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-scroll-area-viewport]::-webkit-scrollbar{display:none}
                  </style>
                  <div class="mantine-xlwgkm mantine-ScrollArea-viewport" data-radix-scroll-area-viewport="" style="overflow-x:hidden;overflow-y:hidden">
                   <div style="min-width:100%;display:table">
                    <pre class="mantine-11jfaka mantine-Prism-code prism-code language-json" dir="ltr" style="color:#212529;background-color:rgba(248, 249, 250, 0.65)"><div class="mantine-1e8ljqt mantine-Prism-line token-line"><div class="mantine-26ugy1 mantine-Prism-lineContent"><span class="token plain">Run a walker to see the result</span></div></div></pre>
                   </div>
                  </div>
                 </div>
                </div>
               </div>
              </div>
             </div>
            </div>
           </div>
          </div>
         </div>
        </div>
       </div>
      </main>
     </div>
    </div>
   </div>
  </div>
  <script id="__NEXT_DATA__" type="application/json">
   {"props":{"pageProps":{}},"page":"/architype","query":{},"buildId":"iiD7YBuGak2wjNaXaNppg","assetPrefix":"/studio","nextExport":true,"autoExport":true,"isFallback":false,"scriptLoader":[]}
  </script>
 </body>
</html>