(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[978],{3419:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/emotion",function(){return t(4918)}])},4918:function(e,n,t){"use strict";t.r(n),t.d(n,{default:function(){return l}});var r=t(5893),i=t(1683),o=t(2712),u=t(4761),c=t(9332),s=t(927);function l(e){let{children:n}=e,t=(0,o.S)();return t.compat=!0,(0,c.useServerInsertedHTML)(()=>(0,r.jsx)("style",{"data-emotion":"".concat(t.key," ").concat(Object.keys(t.inserted).join(" ")),dangerouslySetInnerHTML:{__html:Object.values(t.inserted).join(" ")}})),(0,r.jsx)(i.C,{value:t,children:(0,r.jsx)(u.Me,{theme:s.r,withGlobalStyles:!0,withNormalizeCSS:!0,children:n})})}}},function(e){e.O(0,[774,888,179],function(){return e(e.s=3419)}),_N_E=e.O()}]);