{% load static %}
<!DOCTYPE html>
<html>
 <head>
  <meta charset="utf-8"/>
  <meta content="minimum-scale=1, initial-scale=1, width=device-width" name="viewport"/>
  <link href="ui_kit/components/components.css" type="text/css"/>
  <title>
   Login
  </title>
  <meta content="4" name="next-head-count"/>
  <noscript data-n-css="">
  </noscript>
  <script defer="" nomodule="" src='{% static "/studio/_next/static/chunks/polyfills-c67a75d1b6f99dc8.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/webpack-620c68345e03c539.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/framework-3b5a00d5d7e8d93b.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/main-1844b67c68085ff6.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/pages/_app-3023bf5945430c06.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/76-3f26e2d93951e5cd.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/113-f20cf828040267fc.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/chunks/pages/index-9873ec26aff4396d.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/iiD7YBuGak2wjNaXaNppg/_buildManifest.js" %}'>
  </script>
  <script defer="" src='{% static "/studio/_next/static/iiD7YBuGak2wjNaXaNppg/_ssgManifest.js" %}'>
  </script>
  <style data-emotion="mantine-global zl4edr">
   html{font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%;-ms-text-size-adjust:100%;text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section,figcaption,figure,main{display:block;}h1{font-size:2em;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background:transparent;text-decoration-skip:objects;}a:active,a:hover{outline-width:0;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;}b,strong{font-weight:bolder;}code,kbp,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sup{top:-0.5em;}sub{bottom:-0.25em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;vertical-align:middle;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,[type=reset],[type=submit]{-webkit-appearance:button;}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=checkbox],[type=radio]{box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto;}[type=search]{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}[type=search]::-webkit-search-cancel-button,[type=search]::-webkit-search-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;-moz-appearance:button;-ms-appearance:button;appearance:button;font:inherit;}details,menu{display:block;}summary{display:-webkit-box;display:-webkit-list-item;display:-ms-list-itembox;display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}
  </style>
  <style data-emotion="mantine-global 1j3c5om">
   *,*::before,*::after{box-sizing:border-box;}html{-webkit-print-color-scheme:light;color-scheme:light;}body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;background-color:#fff;color:#000;line-height:1.55;font-size:16px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;}
  </style>
  <style data-emotion="mantine-global wo6pb2">
  </style>
  <style data-emotion="mantine ibbm6b 13jfpqk osix87 hhjyz1 8od8ev p7xtuc 1h8zs6q hv1yhu 1l34ikq khtkeg 3xbgk5 qo1k2 1m3pqry u5apz8 ittua2 12sbrde 1eid6d8 svfr8w 8h0wfz damqzc v3mnuf v9e8w8 10zwz0q lfk3cq f3xa1k w6mrur 1ug31o7 1m7v3jj n4edgc">
   .mantine-ibbm6b{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;box-sizing:border-box;}.mantine-13jfpqk{-webkit-flex:1;-ms-flex:1;flex:1;width:100vw;box-sizing:border-box;min-height:100vh;padding-top:calc(var(--mantine-header-height, 0px) + 16px);padding-bottom:calc(var(--mantine-footer-height, 0px) + 16px);padding-left:calc(var(--mantine-navbar-width, 0px) + 16px);padding-right:calc(var(--mantine-aside-width, 0px) + 16px);}@media (max-width: -1px){.mantine-13jfpqk{padding-right:16px;}}.mantine-osix87{box-sizing:border-box;}.mantine-hhjyz1{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;top:var(--mantine-header-height);left:0;bottom:0;z-index:100;height:100vh;width:80px;position:fixed;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;background-color:#fff;border-right:1px solid #e9ecef;padding:16px;}@media (max-width: 991px){.mantine-hhjyz1[data-hidden]{display:none;}}.mantine-8od8ev{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;}.mantine-p7xtuc{margin-top:50px;-webkit-flex:1;-ms-flex:1;flex:1;box-sizing:border-box;}.mantine-1h8zs6q{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;gap:0;}.mantine-hv1yhu{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;width:50px;height:50px;border-radius:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;color:#495057;}.mantine-hv1yhu:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-hv1yhu:focus:not(:focus-visible){outline:none;}.mantine-hv1yhu:hover{background-color:#f8f9fa;}.mantine-1l34ikq{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;width:50px;height:50px;border-radius:8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;color:#495057;}.mantine-1l34ikq:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1l34ikq:focus:not(:focus-visible){outline:none;}.mantine-1l34ikq:hover{background-color:#f8f9fa;}.mantine-1l34ikq,.mantine-1l34ikq:hover{background-color:rgba(255, 244, 230, 1);color:#fd7e14;}.mantine-khtkeg{-webkit-flex:0;-ms-flex:0;flex:0;box-sizing:border-box;}.mantine-3xbgk5{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;-webkit-justify-content:center;justify-content:center;height:100%;overflow:visible;}.mantine-qo1k2{white-space:nowrap;height:100%;overflow:hidden;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;}.mantine-1m3pqry{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;line-height:1.55;}.mantine-u5apz8{color:#fa5252;}.mantine-ittua2{display:inline-block;font-size:14px;font-weight:500;color:#212529;word-break:break-word;cursor:default;-webkit-tap-highlight-color:transparent;}.mantine-12sbrde{position:relative;}.mantine-1eid6d8{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;padding:8px;-webkit-flex-basis:66.66666666666667%;-ms-flex-preferred-size:66.66666666666667%;flex-basis:66.66666666666667%;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;max-width:66.66666666666667%;}@media (min-width: 576px){.mantine-1eid6d8{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 768px){.mantine-1eid6d8{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 992px){.mantine-1eid6d8{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1200px){.mantine-1eid6d8{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1400px){.mantine-1eid6d8{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}.mantine-svfr8w{box-sizing:border-box;-webkit-box-flex:0;-webkit-flex-grow:0;-ms-flex-positive:0;flex-grow:0;padding:8px;-webkit-flex-basis:33.333333333333336%;-ms-flex-preferred-size:33.333333333333336%;flex-basis:33.333333333333336%;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;max-width:33.333333333333336%;}@media (min-width: 576px){.mantine-svfr8w{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 768px){.mantine-svfr8w{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 992px){.mantine-svfr8w{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1200px){.mantine-svfr8w{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}@media (min-width: 1400px){.mantine-svfr8w{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;}}.mantine-8h0wfz{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-align-items:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100vh;}.mantine-damqzc{outline:0;-webkit-tap-highlight-color:transparent;display:block;-webkit-text-decoration:none;text-decoration:none;color:#000;background-color:#fff;box-sizing:border-box;border-radius:8px;box-shadow:0 1px 3px rgba(0, 0, 0, 0.05),rgba(0, 0, 0, 0.05) 0px 20px 25px -5px,rgba(0, 0, 0, 0.04) 0px 10px 10px -5px;border:1px solid #dee2e6;position:relative;overflow:hidden;background-color:#fff;width:95%;max-width:600px;margin:0 auto;padding:30px;}.mantine-v3mnuf{margin-bottom:24px;}.mantine-v9e8w8{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;color:inherit;font-size:inherit;line-height:1.55;-webkit-text-decoration:none;text-decoration:none;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;font-weight:700;font-size:34px;line-height:1.3;margin:0;}.mantine-v9e8w8:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-v9e8w8:focus:not(:focus-visible){outline:none;}.mantine-10zwz0q{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;color:#868e96;font-size:inherit;line-height:1.55;-webkit-text-decoration:none;text-decoration:none;}.mantine-10zwz0q:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-10zwz0q:focus:not(:focus-visible){outline:none;}.mantine-lfk3cq{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-direction:column;-ms-flex-direction:column;flex-direction:column;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;-webkit-box-pack:top;-ms-flex-pack:top;-webkit-justify-content:top;justify-content:top;gap:16px;}.mantine-f3xa1k{margin:-8px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-flex-wrap:wrap;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:start;-ms-flex-pack:start;-webkit-justify-content:flex-start;justify-content:flex-start;-webkit-align-items:stretch;-webkit-box-align:stretch;-ms-flex-align:stretch;align-items:stretch;width:100%;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;}.mantine-w6mrur{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;height:36px;-webkit-tap-highlight-color:transparent;line-height:34px;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;resize:none;box-sizing:border-box;font-size:14px;width:100%;color:#000;display:block;text-align:left;min-height:36px;padding-left:12px;padding-right:12px;border-radius:4px;border:1px solid #ced4da;background-color:#fff;-webkit-transition:border-color 100ms ease;transition:border-color 100ms ease;}.mantine-w6mrur:disabled{background-color:#f1f3f5;color:#909296;opacity:0.6;cursor:not-allowed;}.mantine-w6mrur:disabled::-webkit-input-placeholder{color:#909296;}.mantine-w6mrur:disabled::-moz-placeholder{color:#909296;}.mantine-w6mrur:disabled:-ms-input-placeholder{color:#909296;}.mantine-w6mrur:disabled::placeholder{color:#909296;}.mantine-w6mrur::-webkit-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-w6mrur::-moz-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-w6mrur:-ms-input-placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-w6mrur::placeholder{opacity:1;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#adb5bd;}.mantine-w6mrur::-webkit-inner-spin-button,.mantine-w6mrur::-webkit-outer-spin-button,.mantine-w6mrur::-webkit-search-decoration,.mantine-w6mrur::-webkit-search-cancel-button,.mantine-w6mrur::-webkit-search-results-button,.mantine-w6mrur::-webkit-search-results-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}.mantine-w6mrur[type=number]{-moz-appearance:textfield;}.mantine-w6mrur:focus,.mantine-w6mrur:focus-within{outline:none;border-color:#fd7e14;}.mantine-1ug31o7{margin-top:20px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-webkit-justify-content:space-between;justify-content:space-between;}.mantine-1m7v3jj{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;height:36px;padding-left:18px;padding-right:18px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;display:inline-block;width:auto;border-radius:4px;font-weight:600;position:relative;line-height:1;font-size:14px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;border:1px solid transparent;background-color:#868e96;color:#fff;}.mantine-1m7v3jj:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1m7v3jj:focus:not(:focus-visible){outline:none;}.mantine-1m7v3jj:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-1m7v3jj:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-1m7v3jj:hover{background-color:#495057;}}@media (hover: none){.mantine-1m7v3jj:active{background-color:#495057;}}.mantine-1m7v3jj:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-1m7v3jj:disabled,.mantine-1m7v3jj[data-disabled]{border-color:transparent;background-color:#e9ecef;color:#adb5bd;cursor:not-allowed;background-image:none;pointer-events:none;}.mantine-1m7v3jj:disabled:active,.mantine-1m7v3jj[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-1m7v3jj[data-loading]{pointer-events:none;}.mantine-1m7v3jj[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}.mantine-n4edgc{-webkit-tap-highlight-color:transparent;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;cursor:pointer;border:0;padding:0;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;font-size:16px;background-color:transparent;text-align:left;color:#000;-webkit-text-decoration:none;text-decoration:none;box-sizing:border-box;height:36px;padding-left:18px;padding-right:18px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;-webkit-tap-highlight-color:transparent;display:inline-block;width:auto;border-radius:4px;font-weight:600;position:relative;line-height:1;font-size:14px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer;border:1px solid transparent;background-color:#12b886;color:#fff;}.mantine-n4edgc:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-n4edgc:focus:not(:focus-visible){outline:none;}.mantine-n4edgc:focus{outline-offset:2px;outline:2px solid #ff922b;}.mantine-n4edgc:focus:not(:focus-visible){outline:none;}@media (hover: hover){.mantine-n4edgc:hover{background-color:#0ca678;}}@media (hover: none){.mantine-n4edgc:active{background-color:#0ca678;}}.mantine-n4edgc:active{-webkit-transform:translateY(1px);-moz-transform:translateY(1px);-ms-transform:translateY(1px);transform:translateY(1px);}.mantine-n4edgc:disabled,.mantine-n4edgc[data-disabled]{border-color:transparent;background-color:#e9ecef;color:#adb5bd;cursor:not-allowed;background-image:none;pointer-events:none;}.mantine-n4edgc:disabled:active,.mantine-n4edgc[data-disabled]:active{-webkit-transform:none;-moz-transform:none;-ms-transform:none;transform:none;}.mantine-n4edgc[data-loading]{pointer-events:none;}.mantine-n4edgc[data-loading]::before{content:"";position:absolute;top:-1px;left:-1px;right:-1px;bottom:-1px;background-color:rgba(255, 255, 255, .5);border-radius:4px;cursor:not-allowed;}
  </style>
  <script>
   window.django = {is_authenticated: "{{ request.user.is_authenticated }}" === "True" ? true : false, user: "{{request.user}}"};
  </script>
 </head>
 <body>
  <div id="__next">
   <script src='{% static "/studio/ui_kit/components/components.esm.js" %}' type="module">
   </script>
   <script nomodule="" src='{% static "/studio/ui_kit/components/components.js" %}'>
   </script>
   <style data-emotion="css-global zl4edr">
    html{font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-moz-text-size-adjust:100%;-ms-text-size-adjust:100%;text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section,figcaption,figure,main{display:block;}h1{font-size:2em;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background:transparent;text-decoration-skip:objects;}a:active,a:hover{outline-width:0;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;}b,strong{font-weight:bolder;}code,kbp,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sup{top:-0.5em;}sub{bottom:-0.25em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;vertical-align:middle;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,[type=reset],[type=submit]{-webkit-appearance:button;}button::-moz-focus-inner,[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring{outline:1px dotted ButtonText;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=checkbox],[type=radio]{box-sizing:border-box;padding:0;}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto;}[type=search]{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}[type=search]::-webkit-search-cancel-button,[type=search]::-webkit-search-decoration{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;-moz-appearance:button;-ms-appearance:button;appearance:button;font:inherit;}details,menu{display:block;}summary{display:-webkit-box;display:-webkit-list-item;display:-ms-list-itembox;display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}
   </style>
   <style data-emotion="css-global 1j3c5om">
    *,*::before,*::after{box-sizing:border-box;}html{-webkit-print-color-scheme:light;color-scheme:light;}body{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;background-color:#fff;color:#000;line-height:1.55;font-size:16px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;}
   </style>
   <style data-emotion="css-global wo6pb2">
   </style>
   <div data-theme="greenheart">
    <div class="mantine-AppShell-root mantine-osix87">
     <div class="mantine-ibbm6b mantine-AppShell-body">
      <nav class="mantine-Navbar-root mantine-hhjyz1">
       <div class="mantine-8od8ev">
        <img alt="Jaseci Logo" height="42" src="/static/studio/Jaseci-Submark.png" width="40"/>
       </div>
       <div class="mantine-p7xtuc">
        <div class="mantine-Stack-root mantine-1h8zs6q">
         <button class="mantine-UnstyledButton-root mantine-1l34ikq" type="button">
          <svg class="icon icon-tabler icon-tabler-home-2" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="5 12 3 12 12 3 21 12 19 12">
           </polyline>
           <path d="M5 12v7a2 2 0 0 0 2 2h10a2 2 0 0 0 2 -2v-7">
           </path>
           <rect height="4" width="4" x="10" y="12">
           </rect>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-gauge" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <circle cx="12" cy="12" r="9">
           </circle>
           <circle cx="12" cy="12" r="1">
           </circle>
           <line x1="13.41" x2="16" y1="10.59" y2="8">
           </line>
           <path d="M7 12a5 5 0 0 1 5 -5">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-vector-bezier-circle" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <rect height="4" rx="1" width="4" x="3" y="10">
           </rect>
           <rect height="4" rx="1" width="4" x="17" y="10">
           </rect>
           <rect height="4" rx="1" width="4" x="10" y="3">
           </rect>
           <rect height="4" rx="1" width="4" x="10" y="17">
           </rect>
           <path d="M19 10a5 5 0 0 0 -5 -5">
           </path>
           <path d="M19 14a5 5 0 0 1 -5 5">
           </path>
           <path d="M5 14a5 5 0 0 0 5 5">
           </path>
           <path d="M5 10a5 5 0 0 1 5 -5">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-prompt" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="5 7 10 12 5 17">
           </polyline>
           <line x1="13" x2="19" y1="17" y2="17">
           </line>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-server-bolt" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <rect height="8" rx="3" width="18" x="3" y="4">
           </rect>
           <path d="M15 20h-9a3 3 0 0 1 -3 -3v-2a3 3 0 0 1 3 -3h12">
           </path>
           <path d="M7 8v.01">
           </path>
           <path d="M7 16v.01">
           </path>
           <path d="M20 15l-2 3h3l-2 3">
           </path>
          </svg>
         </button>
         <button class="mantine-UnstyledButton-root mantine-hv1yhu" type="button">
          <svg class="icon icon-tabler icon-tabler-code" fill="none" height="24" stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" viewbox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg">
           <path d="M0 0h24v24H0z" fill="none" stroke="none">
           </path>
           <polyline points="7 8 3 12 7 16">
           </polyline>
           <polyline points="17 8 21 12 17 16">
           </polyline>
           <line x1="14" x2="10" y1="4" y2="20">
           </line>
          </svg>
         </button>
        </div>
       </div>
       <div class="mantine-khtkeg">
        <div class="mantine-Stack-root mantine-1h8zs6q">
        </div>
       </div>
       <style data-emotion="css-global 563mdc">
        :root{--mantine-navbar-width:80px;}
       </style>
      </nav>
      <main class="mantine-13jfpqk mantine-AppShell-main">
       <div>
        <div class="mantine-8h0wfz">
         <div class="mantine-Paper-root mantine-Card-root mantine-damqzc">
          <form>
           <div class="mantine-v3mnuf">
            <h1 class="mantine-Text-root mantine-Title-root mantine-v9e8w8">
             Login
            </h1>
            <div class="mantine-Text-root mantine-10zwz0q">
             Connect to a server to start
            </div>
           </div>
           <div class="mantine-Stack-root mantine-lfk3cq">
            <div class="mantine-Grid-root mantine-f3xa1k">
             <div class="mantine-Col-root mantine-1eid6d8">
              <div class="mantine-InputWrapper-root mantine-TextInput-root mantine-1m3pqry">
               <label class="mantine-InputWrapper-label mantine-TextInput-label mantine-ittua2" for="mantine-R2dlam6" id="mantine-R2dlam6-label">
                Host
                <span aria-hidden="true" class="mantine-u5apz8 mantine-InputWrapper-required mantine-TextInput-required">
                 *
                </span>
               </label>
               <div class="mantine-Input-wrapper mantine-TextInput-wrapper mantine-12sbrde">
                <input aria-invalid="false" class="mantine-Input-input mantine-TextInput-input mantine-w6mrur" id="mantine-R2dlam6" placeholder="Enter host e.g localhost" required="" type="text"/>
               </div>
              </div>
             </div>
             <div class="mantine-Col-root mantine-svfr8w">
              <div class="mantine-InputWrapper-root mantine-TextInput-root mantine-1m3pqry">
               <label class="mantine-InputWrapper-label mantine-TextInput-label mantine-ittua2" for="mantine-R4dlam6" id="mantine-R4dlam6-label">
                Port
               </label>
               <div class="mantine-Input-wrapper mantine-TextInput-wrapper mantine-12sbrde">
                <input aria-invalid="false" class="mantine-Input-input mantine-TextInput-input mantine-w6mrur" id="mantine-R4dlam6" placeholder="Enter port e.g 8888" type="text"/>
               </div>
              </div>
             </div>
            </div>
            <div class="mantine-InputWrapper-root mantine-TextInput-root mantine-1m3pqry">
             <label class="mantine-InputWrapper-label mantine-TextInput-label mantine-ittua2" for="mantine-Rllam6" id="mantine-Rllam6-label">
              Email
              <span aria-hidden="true" class="mantine-u5apz8 mantine-InputWrapper-required mantine-TextInput-required">
               *
              </span>
             </label>
             <div class="mantine-Input-wrapper mantine-TextInput-wrapper mantine-12sbrde">
              <input aria-invalid="false" class="mantine-Input-input mantine-TextInput-input mantine-w6mrur" id="mantine-Rllam6" placeholder="Enter your email" required="" type="text"/>
             </div>
            </div>
            <div class="mantine-InputWrapper-root mantine-TextInput-root mantine-1m3pqry">
             <label class="mantine-InputWrapper-label mantine-TextInput-label mantine-ittua2" for="mantine-Rtlam6" id="mantine-Rtlam6-label">
              Password
              <span aria-hidden="true" class="mantine-u5apz8 mantine-InputWrapper-required mantine-TextInput-required">
               *
              </span>
             </label>
             <div class="mantine-Input-wrapper mantine-TextInput-wrapper mantine-12sbrde">
              <input aria-invalid="false" class="mantine-Input-input mantine-TextInput-input mantine-w6mrur" id="mantine-Rtlam6" placeholder="Enter your password" required="" type="password"/>
             </div>
            </div>
            <div class="mantine-1ug31o7">
             <button class="mantine-UnstyledButton-root mantine-Button-root mantine-1m7v3jj" data-button="true" type="submit">
              <div class="mantine-3xbgk5 mantine-Button-inner">
               <span class="mantine-qo1k2 mantine-Button-label">
                Test Connection
               </span>
              </div>
             </button>
             <button aria-label="Connect to Server" class="mantine-UnstyledButton-root mantine-Button-root mantine-n4edgc" data-button="true" type="submit">
              <div class="mantine-3xbgk5 mantine-Button-inner">
               <span class="mantine-qo1k2 mantine-Button-label">
                Connect
               </span>
              </div>
             </button>
            </div>
           </div>
          </form>
         </div>
        </div>
       </div>
      </main>
     </div>
    </div>
   </div>
  </div>
  <script id="__NEXT_DATA__" type="application/json">
   {"props":{"pageProps":{}},"page":"/","query":{},"buildId":"iiD7YBuGak2wjNaXaNppg","assetPrefix":"/studio","nextExport":true,"autoExport":true,"isFallback":false,"scriptLoader":[]}
  </script>
 </body>
</html>