@font-face{font-family:__IBM_Plex_Mono_60d3dc;font-style:normal;font-weight:400;font-display:optional;src:url(/studio/_next/static/media/ebec2867f40f78ec.woff2) format("woff2");unicode-range:U+0460-052f,U+1c80-1c88,U+20b4,U+2de0-2dff,U+a640-a69f,U+fe2e-fe2f}@font-face{font-family:__IBM_Plex_Mono_60d3dc;font-style:normal;font-weight:400;font-display:optional;src:url(/studio/_next/static/media/d607327a37a507c7.woff2) format("woff2");unicode-range:U+0301,U+0400-045f,U+0490-0491,U+04b0-04b1,U+2116}@font-face{font-family:__IBM_Plex_Mono_60d3dc;font-style:normal;font-weight:400;font-display:optional;src:url(/studio/_next/static/media/2e1b830192b7974a.woff2) format("woff2");unicode-range:U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01a0-01a1,U+01af-01b0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1ea0-1ef9,U+20ab}@font-face{font-family:__IBM_Plex_Mono_60d3dc;font-style:normal;font-weight:400;font-display:optional;src:url(/studio/_next/static/media/3aa27b2eb5f698f7.woff2) format("woff2");unicode-range:U+0100-02af,U+0304,U+0308,U+0329,U+1e00-1e9f,U+1ef2-1eff,U+2020,U+20a0-20ab,U+20ad-20cf,U+2113,U+2c60-2c7f,U+a720-a7ff}@font-face{font-family:__IBM_Plex_Mono_60d3dc;font-style:normal;font-weight:400;font-display:optional;src:url(/studio/_next/static/media/3478b6abef19b3b3.p.woff2) format("woff2");unicode-range:U+00??,U+0131,U+0152-0153,U+02bb-02bc,U+02c6,U+02da,U+02dc,U+0304,U+0308,U+0329,U+2000-206f,U+2074,U+20ac,U+2122,U+2191,U+2193,U+2212,U+2215,U+feff,U+fffd}@font-face{font-family:__IBM_Plex_Mono_Fallback_60d3dc;src:local("Arial");ascent-override:77.95%;descent-override:20.91%;line-gap-override:0.00%;size-adjust:131.49%}.__className_60d3dc{font-family:__IBM_Plex_Mono_60d3dc,__IBM_Plex_Mono_Fallback_60d3dc;font-weight:400;font-style:normal}